@@ -1,5 +1,5 @@
 from .imports import *
-def get_caller_path():
+def get_caller_path(i=None):
     i = i or 1
     frame = inspect.stack()[i]
     return os.path.abspath(frame.filename)
