@@ -1,5 +1,5 @@
 from ...type_utils  import is_number,make_list
-from .function_utils import extract_imports
+from .function_utils import *
 from pathlib import Path
 from typing import *
 def get_dot_range(filepath=None,list_obj=None):
@@ -11,7 +11,7 @@ def get_dot_range(filepath=None,list_obj=None):
         dots.sort()
         highest = dots[0]
     return highest
-def _dotted_from(file: Path, sysroot: Path) -> str:
+def dotted_from(file: Path, sysroot: Path) -> str:
     """
     Build dotted name from sysroot (directory *above* top package)
     e.g.  /repo/abstract_ide/consoles/launcherWindowTab/functions/core_utils.py
