@@ -6,9 +6,17 @@ def call_for_all_tabs(root = None,tab_control=True):
     root = root or get_caller_dir()
     get_for_all_tabs(root,tab_control=tab_control)
 
-def clean_imports():
+def get_clean_list(*args):
+    objs = []
+    for arg in args:
+        objs+= make_list(arg)
+    return list(set(objs))
+def clean_imports(*args,**kwargs):
+    for pkg,imps in kwargs.items():
+        f"from {pkg} import make_list(imps)"
+        
     alls = str(list(set("""os,re,subprocess,sys,re,traceback,pydot, enum, inspect, sys, traceback, threading,json,traceback,logging,requests""".replace('\n','').replace(' ','').replace('\t','').split(','))))[1:-1].replace('"','').replace("'",'')
-    input(alls)
+    return 
 def isTab(item):
     item_lower =  item.lower()
     for key in ['console','tab']:
